.. include global.rst

The libvips enums
=================

This module contains the various libvips enums as Python classes.

Enums values are represented in pyvips as strings. These classes contain the 
valid strings for each enum. 

.. automodule:: pyvips.enums
        :members:
